@@ -39,6 +39,14 @@ def check_unreachable(v, lineno, size, name):
     assert item.name == name
 
 
+def check_multiple_unreachable(v, checks):
+    assert len(v.unreachable_code) == len(checks)
+    for item, (lineno, size, name) in zip(v.unreachable_code, checks):
+        assert item.first_lineno == lineno
+        assert item.size == size
+        assert item.name == name
+
+
 @pytest.fixture
 def v():
     return core.Vulture(verbose=True)
