@@ -3,9 +3,10 @@ import os.path
 import subprocess
 import sys
 
-from . import call_vulture, REPO, WHITELISTS
 from vulture.utils import ExitCode
 
+from . import REPO, WHITELISTS, call_vulture
+
 
 def test_module_with_explicit_whitelists():
     assert call_vulture(["vulture/"] + WHITELISTS) == ExitCode.NoDeadCode
