@@ -1,31 +1,11 @@
 import ast
-import sys
 
 from vulture import lines
 
-from . import skip_if_not_has_async
-
-
-def get_last_line_number_slow(node):
-    """
-    A slower, but also simpler and slightly more accurate version of
-    get_last_line_number().
-
-    It traverses all descendants of node and records the highest line
-    number seen.
-
-    This code is 1.6 times slower than count_lines() on the Python
-    subset of tensorflow. It reports the same sizes for all test cases
-    and the functions and classes in tensorflow.
-
-    """
-    return max(getattr(node, "lineno", -1) for node in ast.walk(node))
-
 
 def count_lines(node):
     """Estimate the number of lines of the given AST node."""
     last_lineno = lines.get_last_line_number(node)
-    assert get_last_line_number_slow(node) == last_lineno
     return last_lineno - lines.get_first_line_number(node) + 1
 
 
@@ -212,7 +192,7 @@ class Foo:
             'long'
             'string')
 """
-    check_size(example, 4)
+    check_size(example, 6)
 
 
 # We currently cannot handle code ending with comment lines.
@@ -305,21 +285,16 @@ class Foo:
     [a, b
     ]
 """
-    check_size(example, 2)
+    check_size(example, 3)
 
 
-# We currently cannot handle code ending with an ellipsis on Python 2.
 def test_size_ellipsis():
     example = """
 class Foo:
     bar[1:2,
         ...]
 """
-    if sys.version_info < (3, 0):
-        check_size(example, 2)
-    else:
-        # ast.Ellipsis is a subclass of ast.expr in Python 3.
-        check_size(example, 3)
+    check_size(example, 3)
 
 
 def test_size_starargs():
@@ -343,7 +318,6 @@ class Foo:
     check_size(example, 2)
 
 
-@skip_if_not_has_async
 def test_size_async_function_def():
     example = """
 class Foo:
@@ -353,7 +327,6 @@ class Foo:
     check_size(example, 3)
 
 
-@skip_if_not_has_async
 def test_size_async_with():
     example = """
 class Foo:
@@ -364,7 +337,6 @@ class Foo:
     check_size(example, 4)
 
 
-@skip_if_not_has_async
 def test_size_async_for():
     example = """
 class Foo:
